import { Box, Card, FlexBox, GridBox, Text } from '@codecademy/gamut';
import { LevelIcon } from '@codecademy/gamut-icons';
import { Background } from '@codecademy/gamut-styles';
import pluralize from 'pluralize';
import React from 'react';
import { Divider } from './shared';
import { CourseDifficulty, EnrollmentStatus } from './types';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
var Image = Box.withComponent('img', {
  target: "e1xnma750",
  label: "Image"
});
export var ContentGroupBaseCard = function ContentGroupBaseCard(_ref) {
  var headerBackgroundColor = _ref.headerBackgroundColor,
    headerText = _ref.headerText,
    title = _ref.title,
    headingLevel = _ref.headingLevel,
    description = _ref.description,
    difficulty = _ref.difficulty,
    numLessons = _ref.numLessons,
    imageSrc = _ref.imageSrc,
    _ref$isFullSize = _ref.isFullSize,
    isFullSize = _ref$isFullSize === void 0 ? false : _ref$isFullSize,
    _ref$shadow = _ref.shadow,
    shadow = _ref$shadow === void 0 ? 'medium' : _ref$shadow,
    enrollmentStatus = _ref.enrollmentStatus,
    children = _ref.children;
  var enrollmentAssets = {
    completed: {
      text: headerText + ' completed!',
      backgroundColor: 'green'
    },
    inProgress: {
      text: 'In progress...',
      backgroundColor: 'yellow'
    },
    none: {
      text: headerText,
      backgroundColor: headerBackgroundColor
    }
  };
  var isEnrolled = enrollmentStatus === EnrollmentStatus.InProgress || enrollmentStatus === EnrollmentStatus.Completed;
  return /*#__PURE__*/_jsxs(Card, {
    variant: isEnrolled ? 'beige' : 'white',
    borderRadius: "4px",
    borderColor: "navy",
    overflow: "hidden",
    display: "flex",
    flexDirection: "column",
    shadow: shadow,
    p: 0,
    height: "100%",
    children: [/*#__PURE__*/_jsx(Background, {
      bg: enrollmentStatus ? enrollmentAssets[enrollmentStatus].backgroundColor : headerBackgroundColor,
      pl: 12,
      py: 4,
      border: 1,
      borderColor: "white",
      borderRadius: "4px 4px 0 0",
      borderBottom: "none",
      children: /*#__PURE__*/_jsx(Text, {
        fontFamily: "accent",
        fontSize: 14,
        children: enrollmentStatus ? enrollmentAssets[enrollmentStatus].text : headerText
      })
    }), /*#__PURE__*/_jsxs(GridBox, {
      gridAutoFlow: "column",
      columnGap: isFullSize ? 16 : undefined,
      px: 12,
      pt: 4,
      pb: 8,
      height: "100%",
      children: [/*#__PURE__*/_jsxs(FlexBox, {
        flexDirection: "column",
        textAlign: "left",
        children: [/*#__PURE__*/_jsxs(Box, {
          children: [/*#__PURE__*/_jsx(Text, {
            variant: "title-xs",
            as: headingLevel,
            pt: 12,
            pb: 4,
            children: title
          }), description && /*#__PURE__*/_jsx(Text, {
            variant: "p-small",
            truncate: "ellipsis",
            truncateLines: 3,
            mb: 16,
            children: description
          })]
        }), /*#__PURE__*/_jsxs(Box, {
          mt: "auto",
          children: [children, /*#__PURE__*/_jsx(Divider, {}), /*#__PURE__*/_jsxs(FlexBox, {
            justifyContent: "space-between",
            children: [difficulty && /*#__PURE__*/_jsxs(FlexBox, {
              alignItems: "center",
              children: [/*#__PURE__*/_jsx(FlexBox, {
                pr: 4,
                children: /*#__PURE__*/_jsx(LevelIcon, {})
              }), /*#__PURE__*/_jsxs(Text, {
                variant: "p-small",
                pl: 4,
                whiteSpace: "nowrap",
                "data-testid": "card-difficulty",
                children: [/*#__PURE__*/_jsx("b", {
                  children: difficulty
                }), difficulty === CourseDifficulty.Beginner && /*#__PURE__*/_jsx(_Fragment, {
                  children: " Friendly"
                })]
              })]
            }), numLessons > 0 && /*#__PURE__*/_jsx(FlexBox, {
              children: /*#__PURE__*/_jsxs(Text, {
                variant: "p-small",
                pl: 4,
                whiteSpace: "nowrap",
                "data-testid": "card-num-lessons",
                children: [/*#__PURE__*/_jsx("b", {
                  children: numLessons
                }), " ", pluralize('Lessons', numLessons)]
              })
            })]
          })]
        })]
      }), /*#__PURE__*/_jsx(Box, {
        display: isFullSize ? {
          _: 'none',
          md: 'flex'
        } : 'none',
        alignItems: "center",
        px: 64,
        children: /*#__PURE__*/_jsx(Image, {
          "aria-hidden": true,
          width: 100,
          height: 100,
          src: imageSrc
        })
      })]
    })]
  });
};